==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/filedesc/translations/filedesc_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Fichier avec une description à synchroniser</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Entrez ici un fichier, qui contiendra des descriptions à mettre à jour par le module.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Si vous choisissez le statut sans description, le module va le mettre automatiquement à semblable, mais avec la description</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Autoriser d&apos;autres descriptions</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Permet de définir une description personnalisée manuellement, tant que le contenu du fichier ne change pas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Toujours ajouter la description sur l&apos;état d&apos;activité</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/filedesc/translations/filedesc_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Fichier avec une description à synchroniser</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Entrez ici un fichier, qui contiendra des descriptions à mettre à jour par le module.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Si vous choisissez le statut sans description, le module va le mettre automatiquement à semblable, mais avec la description</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Autoriser d&apos;autres descriptions</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Permet de définir une description personnalisée manuellement, tant que le contenu du fichier ne change pas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Toujours ajouter la description sur l&apos;état d&apos;activité</translation>
    </message>
</context>
</TS>
